@@ -1,5 +1,7 @@
 """Django urlpatterns declaration for Welcome Wizard plugin."""
+from django.templatetags.static import static
 from django.urls import path
+from django.views.generic import RedirectView
 
 from . import views
 
@@ -19,4 +21,9 @@ urlpatterns = [
         views.DeviceTypeBulkImportView.as_view(),
         name="devicetype_import",
     ),
+    path(
+        "docs/",
+        RedirectView.as_view(url=static("welcome_wizard/docs/index.html")),
+        name="docs",
+    ),
 ]
